lidarwind.wind\_prop\_retrieval.RetriveWindFFT
==============================================

.. currentmodule:: lidarwind.wind_prop_retrieval

.. autoclass:: RetriveWindFFT

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~RetriveWindFFT.__init__
      ~RetriveWindFFT.get_beta
      ~RetriveWindFFT.load_attrs
      ~RetriveWindFFT.ret_hor_wind_data
      ~RetriveWindFFT.ret_vert_wind_data
   
   

   
   
   